import unittest
from obj2html import obj2html
import os

class TestObj2Html(unittest.TestCase):
    def setUp(self):
        self.model_assets_path = 'test/assets/model.obj'

    def test_obj2html_without_output_file_path(self):
        string_out = obj2html(self.model_assets_path)

        self.assertTrue(isinstance(string_out, str))

    def test_obj2html_write_html_file(self):
        html_path = '/tmp/index.html'
        if os.path.isfile(html_path):
            os.remove(html_path) 

        self.assertFalse(os.path.isfile(html_path))
        
        obj2html(self.model_assets_path, html_path)

        self.assertTrue(os.path.isfile(html_path))
        os.remove(html_path) 

if __name__ == '__main__':
    unittest.main()



import json

html1 = """
<!DOCTYPE html>
<html lang="">
  <head>
    <meta charset="utf-8">
    <title></title>

    <script type="module">
var obj_3d = """

html2 = """
import * as THREE from 'https://threejsfundamentals.org/threejs/resources/threejs/r132/build/three.module.js';
import {OrbitControls} from 'https://threejsfundamentals.org/threejs/resources/threejs/r132/examples/jsm/controls/OrbitControls.js';
import {OBJLoader} from 'https://threejsfundamentals.org/threejs/resources/threejs/r132/examples/jsm/loaders/OBJLoader.js';

function main() {
  const canvas = document.querySelector('#c');
  const renderer = new THREE.WebGLRenderer({canvas});

  const fov = 45;
  const aspect = 2;  // the canvas default
  const near = 0.1;
  const far = 100;
  const camera = new THREE.PerspectiveCamera(fov, aspect, near, far);
  camera.position.set(0, 10, 20);

  const controls = new OrbitControls(camera, canvas);
  controls.target.set(0, 5, 0);
  controls.update();

  const scene = new THREE.Scene();
  scene.background = new THREE.Color('black');

  {
    const skyColor = 0xB1E1FF;  // light blue
    const groundColor = 0xB97A20;  // brownish orange
    const intensity = 1;
    const light = new THREE.HemisphereLight(skyColor, groundColor, intensity);
    scene.add(light);
  }

  {
    const color = 0xFFFFFF;
    const intensity = 1;
    const light = new THREE.DirectionalLight(color, intensity);
    light.position.set(0, 10, 0);
    light.target.position.set(-5, 0, 0);
    scene.add(light);
    scene.add(light.target);
  }

  {
    const objLoader = new OBJLoader();
    const mesh = objLoader.parse(obj_3d['obj']);
    mesh.scale.set(30, 30, 30);
    scene.add(mesh);
  }

  function resizeRendererToDisplaySize(renderer) {
    const canvas = renderer.domElement;
    const width = canvas.clientWidth;
    const height = canvas.clientHeight;
    const needResize = canvas.width !== width || canvas.height !== height;
    if (needResize) {
      renderer.setSize(width, height, false);
    }
    return needResize;
  }

  function render() {

    if (resizeRendererToDisplaySize(renderer)) {
      const canvas = renderer.domElement;
      camera.aspect = canvas.clientWidth / canvas.clientHeight;
      camera.updateProjectionMatrix();
    }

    renderer.render(scene, camera);

    requestAnimationFrame(render);
  }

  requestAnimationFrame(render);
}

main();

    </script>
  </head>
  <body>
    <canvas id="c"></canvas>
  </body>
</html>

"""

def obj2html(obj_path, output_html_path=None):
    with  open(obj_path, "r") as f:
        content = f.readlines()
    content = '\n'.join(content)
    js_cont = {'obj': content}
    js_string = json.dumps(js_cont)
    html_string = html1+js_string+html2
    if output_html_path != None:
        with  open(output_html_path, "w") as f:
            f.write(html_string)
    else:
        return html_string



from distutils.core import setup

long_des = """obj2html lib
=============================

You can use that lib to create html file from a .obj path:

    from obj2html import obj2html

    html_string = obj2html(obj_path)

    obj2html(obj_path, 'index.html')

    # firefox index.html

Use in a Jupyter notebook to display a .obj 3D file:

    ! pip install 
    
    from obj2html import obj2html

    from IPython.display import display, HTML

    obj_path = 'model.obj'

    obj2html(obj_path, 'index.html')

    display(HTML('index.html'))

"""

setup(
  name = 'obj2html',
  packages = ['obj2html'],
  version = '0.3',
  license='MIT',
  description = 'Create an html with three.js that contains the given .obj file.',
  long_description = long_des,
  author = 'Nicola Landro',
  author_email = 'nicolaxx94@live.it',
  url = 'https://gitlab.com/nicolalandro/obj2html',
  keywords = ['3D', '.obj', '.html', 'jupyter', '3D viewer'],
)